.. image:: https://img.shields.io/pypi/v/z3c.macro.svg
        :target: https://pypi.python.org/pypi/z3c.macro/
        :alt: Latest release

.. image:: https://img.shields.io/pypi/pyversions/z3c.macro.svg
        :target: https://pypi.org/project/z3c.macro/
        :alt: Supported Python versions

.. image:: https://travis-ci.org/zopefoundation/z3c.macro.svg?branch=master
        :target: https://travis-ci.org/zopefoundation/z3c.macro

.. image:: https://coveralls.io/repos/github/zopefoundation/z3c.macro/badge.svg?branch=master
        :target: https://coveralls.io/github/zopefoundation/z3c.macro?branch=master

This package provides an adapter and a TALES expression for a more explicit and
more flexible macro handling using the adapter registry for macros.
